summaryrefslogtreecommitdiffstats
path: root/src/komposeviewmanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/komposeviewmanager.cpp')
-rw-r--r--src/komposeviewmanager.cpp64
1 files changed, 32 insertions, 32 deletions
diff --git a/src/komposeviewmanager.cpp b/src/komposeviewmanager.cpp
index 57359d3..0792a55 100644
--- a/src/komposeviewmanager.cpp
+++ b/src/komposeviewmanager.cpp
@@ -16,12 +16,12 @@
#include "komposesettings.h"
#include "komposesystray.h"
-#include <qtimer.h>
-#include <qcursor.h>
-#include <qapplication.h>
-#include <qptrlist.h>
-#include <qwidgetlist.h>
-#include <qdesktopwidget.h>
+#include <tqtimer.h>
+#include <tqcursor.h>
+#include <tqapplication.h>
+#include <tqptrlist.h>
+#include <tqwidgetlist.h>
+#include <tqdesktopwidget.h>
#include <kwin.h>
#include <kapplication.h>
@@ -45,7 +45,7 @@ KomposeViewManager* KomposeViewManager::instance()
KomposeViewManager::KomposeViewManager():
DCOPObject( "KomposeDcopIface" ),
- QObject(),
+ TQObject(),
viewWidget(),
activeView(0),
blockScreenshots(0)
@@ -53,11 +53,11 @@ KomposeViewManager::KomposeViewManager():
viewManagerInstance = this;
// Setup cursorupdate timer to check for mouse moves into corner
- cursorUpdateTimer = new QTimer();
+ cursorUpdateTimer = new TQTimer();
slotStartCursorUpdateTimer();
- // dirty hack. see uglyQtHackInitFunction()
- QTimer::singleShot( 500, this, SLOT( uglyQtHackInitFunction() ) );
+ // dirty hack. see uglyTQtHackInitFunction()
+ TQTimer::singleShot( 500, this, SLOT( uglyTQtHackInitFunction() ) );
}
@@ -70,13 +70,13 @@ KomposeViewManager::~KomposeViewManager()
/**
* This is a hack that should be called by a timer as this connect won't work in the constructor
*/
-void KomposeViewManager::uglyQtHackInitFunction()
+void KomposeViewManager::uglyTQtHackInitFunction()
{
connect( KomposeSettings::instance(), SIGNAL( settingsChanged() ), SLOT( slotStartCursorUpdateTimer() ) );
}
/**
* Starts the corner check timer which polls QCursor::pos() every second
@see checkCursorPos()
*/
void KomposeViewManager::slotStartCursorUpdateTimer()
@@ -92,8 +92,8 @@ void KomposeViewManager::slotStartCursorUpdateTimer()
KomposeSettings::instance()->getActivateOnLeftEdge() ||
KomposeSettings::instance()->getActivateOnRightEdge() )
{
- kdDebug() << "KomposeViewManager::slotStartCursorUpdateTimer() - QCursor::pos() checks enabled" << endl;
- QRect deskRect = QApplication::desktop()->screenGeometry();
+ kdDebug() << "KomposeViewManager::slotStartCursorUpdateTimer() - TQCursor::pos() checks enabled" << endl;
+ TQRect deskRect = TQApplication::desktop()->screenGeometry();
topLeftCorner = deskRect.topLeft();
topRightCorner = deskRect.topRight();
@@ -113,25 +113,25 @@ void KomposeViewManager::checkCursorPos()
{
if (
( KomposeSettings::instance()->getActivateOnTopLeftCorner() &&
- !activeView && QCursor::pos() == topLeftCorner ) ||
+ !activeView && TQCursor::pos() == topLeftCorner ) ||
( KomposeSettings::instance()->getActivateOnTopRightCorner() &&
- !activeView && QCursor::pos() == topRightCorner ) ||
+ !activeView && TQCursor::pos() == topRightCorner ) ||
( KomposeSettings::instance()->getActivateOnBottomLeftCorner() &&
- !activeView && QCursor::pos() == bottomLeftCorner ) ||
+ !activeView && TQCursor::pos() == bottomLeftCorner ) ||
( KomposeSettings::instance()->getActivateOnBottomRightCorner() &&
- !activeView && QCursor::pos() == bottomRightCorner ) ||
+ !activeView && TQCursor::pos() == bottomRightCorner ) ||
( KomposeSettings::instance()->getActivateOnTopEdge() &&
- !activeView && QCursor::pos().y() == topLeftCorner.y() ) ||
+ !activeView && TQCursor::pos().y() == topLeftCorner.y() ) ||
( KomposeSettings::instance()->getActivateOnBottomEdge() &&
- !activeView && QCursor::pos().y() == bottomLeftCorner.y() ) ||
+ !activeView && TQCursor::pos().y() == bottomLeftCorner.y() ) ||
( KomposeSettings::instance()->getActivateOnLeftEdge() &&
- !activeView && QCursor::pos().x() == topLeftCorner.x() ) ||
+ !activeView && TQCursor::pos().x() == topLeftCorner.x() ) ||
( KomposeSettings::instance()->getActivateOnRightEdge() &&
- !activeView && QCursor::pos().x() == topRightCorner.x() )
+ !activeView && TQCursor::pos().x() == topRightCorner.x() )
)
{
//cursorUpdateTimer->stop();
- QTimer::singleShot( KomposeSettings::instance()->getAutoLockDelay(), this, SLOT( reCheckCursorPos() ) );
+ TQTimer::singleShot( KomposeSettings::instance()->getAutoLockDelay(), this, SLOT( reCheckCursorPos() ) );
}
}
@@ -142,21 +142,21 @@ void KomposeViewManager::reCheckCursorPos()
{
if (
( KomposeSettings::instance()->getActivateOnTopLeftCorner() &&
- !activeView && QCursor::pos() == topLeftCorner ) ||
+ !activeView && TQCursor::pos() == topLeftCorner ) ||
( KomposeSettings::instance()->getActivateOnTopRightCorner() &&
- !activeView && QCursor::pos() == topRightCorner ) ||
+ !activeView && TQCursor::pos() == topRightCorner ) ||
( KomposeSettings::instance()->getActivateOnBottomLeftCorner() &&
- !activeView && QCursor::pos() == bottomLeftCorner ) ||
+ !activeView && TQCursor::pos() == bottomLeftCorner ) ||
( KomposeSettings::instance()->getActivateOnBottomRightCorner() &&
- !activeView && QCursor::pos() == bottomRightCorner ) ||
+ !activeView && TQCursor::pos() == bottomRightCorner ) ||
( KomposeSettings::instance()->getActivateOnTopEdge() &&
- !activeView && QCursor::pos().y() == topLeftCorner.y() ) ||
+ !activeView && TQCursor::pos().y() == topLeftCorner.y() ) ||
( KomposeSettings::instance()->getActivateOnBottomEdge() &&
- !activeView && QCursor::pos().y() == bottomLeftCorner.y() ) ||
+ !activeView && TQCursor::pos().y() == bottomLeftCorner.y() ) ||
( KomposeSettings::instance()->getActivateOnLeftEdge() &&
- !activeView && QCursor::pos().x() == topLeftCorner.x() ) ||
+ !activeView && TQCursor::pos().x() == topLeftCorner.x() ) ||
( KomposeSettings::instance()->getActivateOnRightEdge() &&
- !activeView && QCursor::pos().x() == topRightCorner.x() )
+ !activeView && TQCursor::pos().x() == topRightCorner.x() )
)
{
cursorUpdateTimer->stop();
@@ -230,7 +230,7 @@ void KomposeViewManager::closeCurrentView()
KWin::setCurrentDesktop( deskBeforeSnaps );
// A short delay until we allow screenshots again (would cause overlapping else
- QTimer::singleShot( 400, this, SLOT( toggleBlockScreenshots() ) );
+ TQTimer::singleShot( 400, this, SLOT( toggleBlockScreenshots() ) );
// Restart Timer for corner checks
slotStartCursorUpdateTimer();
@@ -70,13 +70,13 @@ KomposeViewManager::~KomposeViewManager()
}
/**
- * Starts the corner check timer which polls QCursor::pos() every second
+ * Starts the corner check timer which polls TQCursor::pos() every second
*/